==> division-0.8.3.tar.gz: lib/src/animated.dart <==
import 'package:flutter/material.dart';

import 'model.dart';
import 'build.dart';

class ParentAnimated extends ImplicitlyAnimatedWidget {
  ParentAnimated({
    @required this.styleModel,
    @required this.gestureModel,
    @required this.child,
  }) : super(curve: styleModel?.curve, duration: styleModel?.duration);

  final Widget child;

  final StyleModel styleModel;

  final GestureModel gestureModel;

  @override
  _ParentAnimatedState createState() => _ParentAnimatedState();
}

class _ParentAnimatedState extends AnimatedWidgetBaseState<ParentAnimated> {
  AlignmentGeometryTween _alignment;
  AlignmentGeometryTween _alignmentChild;
  EdgeInsetsGeometryTween _padding;
  DecorationTween _decoration;
  BoxConstraintsTween _constraints;
  EdgeInsetsGeometryTween _margin;
  Matrix4Tween _transform;
  Tween<double> _blur;
  Tween<double> _opacity;

  @override
  void forEachTween(TweenVisitor<dynamic> visitor) {
    _alignment = visitor(_alignment, widget.styleModel?.alignment,
        (dynamic value) => AlignmentGeometryTween(begin: value));
    _alignmentChild = visitor(
        _alignmentChild,
        widget.styleModel?.alignmentContent,
        (dynamic value) => AlignmentGeometryTween(begin: value));
    _padding = visitor(_padding, widget.styleModel?.padding,
        (dynamic value) => EdgeInsetsGeometryTween(begin: value));
    _decoration = visitor(_decoration, widget.styleModel?.decoration,
        (dynamic value) => DecorationTween(begin: value));
    _constraints = visitor(_constraints, widget.styleModel?.constraints,
        (dynamic value) => BoxConstraintsTween(begin: value));
    _margin = visitor(_margin, widget.styleModel?.margin,
        (dynamic value) => EdgeInsetsGeometryTween(begin: value));
    _transform = visitor(_transform, widget.styleModel?.transform,
        (dynamic value) => Matrix4Tween(begin: value));
    _blur = visitor(_blur, widget.styleModel?.backgroundBlur,
        (dynamic value) => Tween<double>(begin: value));
    _opacity = visitor(_opacity, widget.styleModel?.opacity,
        (dynamic value) => Tween<double>(begin: value));
  }

  @override
  Widget build(BuildContext context) {
    StyleModel _styleModel = widget.styleModel;

    if (_styleModel != null) {
      _styleModel
        ..alignment = _alignment?.evaluate(animation)
        ..alignmentContent = _alignmentChild?.evaluate(animation)
        ..padding = _padding?.evaluate(animation)
        ..setBoxConstraints = _constraints?.evaluate(animation)
        ..setBoxDecoration = _decoration?.evaluate(animation)
        ..margin = _margin?.evaluate(animation)
        ..setTransform = _transform?.evaluate(animation)
        ..backgroundBlur = _blur?.evaluate(animation)
        ..opacity = _opacity?.evaluate(animation);
    }

    return ParentBuild(
      styleModel: _styleModel,
      gestureModel: widget.gestureModel,
      child: widget.child,
    );
  }
}

==> division-0.8.5.tar.gz: lib/src/animated.dart <==
import 'package:flutter/material.dart';

import 'model.dart';
import 'build.dart';

class ParentAnimated extends ImplicitlyAnimatedWidget {
  ParentAnimated({
    @required this.styleModel,
    @required this.gestureModel,
    @required this.child,
  }) : super(curve: styleModel?.curve, duration: styleModel?.duration);

  final Widget child;

  final StyleModel styleModel;

  final GestureModel gestureModel;

  @override
  _ParentAnimatedState createState() => _ParentAnimatedState();
}

class _ParentAnimatedState extends AnimatedWidgetBaseState<ParentAnimated> {
  AlignmentGeometryTween _alignment;
  AlignmentGeometryTween _alignmentContent;
  EdgeInsetsGeometryTween _padding;
  DecorationTween _decoration;
  BoxConstraintsTween _constraints;
  EdgeInsetsGeometryTween _margin;
  Matrix4Tween _transform;
  Tween<double> _blur;
  Tween<double> _opacity;

  @override
  void forEachTween(TweenVisitor<dynamic> visitor) {
    _alignment = visitor(_alignment, widget.styleModel?.alignment,
        (dynamic value) => AlignmentGeometryTween(begin: value));
    _alignmentContent = visitor(
        _alignmentContent,
        widget.styleModel?.alignmentContent,
        (dynamic value) => AlignmentGeometryTween(begin: value));
    _padding = visitor(_padding, widget.styleModel?.padding,
        (dynamic value) => EdgeInsetsGeometryTween(begin: value));
    _decoration = visitor(_decoration, widget.styleModel?.decoration,
        (dynamic value) => DecorationTween(begin: value));
    _constraints = visitor(_constraints, widget.styleModel?.constraints,
        (dynamic value) => BoxConstraintsTween(begin: value));
    _margin = visitor(_margin, widget.styleModel?.margin,
        (dynamic value) => EdgeInsetsGeometryTween(begin: value));
    _transform = visitor(_transform, widget.styleModel?.transform,
        (dynamic value) => Matrix4Tween(begin: value));
    _blur = visitor(_blur, widget.styleModel?.backgroundBlur,
        (dynamic value) => Tween<double>(begin: value));
    _opacity = visitor(_opacity, widget.styleModel?.opacity,
        (dynamic value) => Tween<double>(begin: value));
  }

  @override
  Widget build(BuildContext context) {
    StyleModel _styleModel = widget.styleModel;

    if (_styleModel != null) {
      _styleModel
        ..alignment = _alignment?.evaluate(animation)
        ..alignmentContent = _alignmentContent?.evaluate(animation)
        ..padding = _padding?.evaluate(animation)
        ..setBoxConstraints = _constraints?.evaluate(animation)
        ..setBoxDecoration = _decoration?.evaluate(animation)
        ..margin = _margin?.evaluate(animation)
        ..setTransform = _transform?.evaluate(animation)
        ..backgroundBlur = _blur?.evaluate(animation)
        ..opacity = _opacity?.evaluate(animation);
    }

    return ParentBuild(
      styleModel: _styleModel,
      gestureModel: widget.gestureModel,
      child: widget.child,
    );
  }
}

class TxtAnimated extends ImplicitlyAnimatedWidget {
  TxtAnimated({
    @required this.textModel,
    @required Curve curve,
    @required Duration duration,
    @required this.text,
  }) : super(curve: curve, duration: duration);

  final String text;

  final TextModel textModel;

  @override
  _TxtAnimatedState createState() => _TxtAnimatedState();
}

class _TxtAnimatedState extends AnimatedWidgetBaseState<TxtAnimated> {
  Tween<double> _fontSize;
  ColorTween _textColor;
  Tween<int> _maxLines;
  Tween<double> _letterSpacing;
  Tween<double> _wordSpacing;

  @override
  void forEachTween(TweenVisitor<dynamic> visitor) {
    _fontSize = visitor(_fontSize, widget.textModel?.fontSize,
        (dynamic value) => Tween<double>(begin: value));
    _textColor = visitor(_textColor, widget.textModel?.textColor,
        (dynamic value) => ColorTween(begin: value));
    _maxLines = visitor(_maxLines, widget.textModel?.maxLines,
        (dynamic value) => Tween<int>(begin: value));
    _letterSpacing = visitor(_letterSpacing, widget.textModel?.letterSpacing,
        (dynamic value) => Tween<double>(begin: value));
    _wordSpacing = visitor(_wordSpacing, widget.textModel?.wordSpacing,
        (dynamic value) => Tween<double>(begin: value));
  }

  @override
  Widget build(BuildContext context) {
    TextModel _textModel = widget.textModel;

    if (_textModel != null) {
      _textModel
        ..fontSize = _fontSize?.evaluate(animation)
        ..textColor = _textColor?.evaluate(animation)
        ..maxLines = _maxLines?.evaluate(animation)
        ..letterSpacing = _letterSpacing?.evaluate(animation)
        ..wordSpacing = _wordSpacing?.evaluate(animation);
    }

    if (_textModel?.editable != null && _textModel?.editable == true) {
      return TxtBuildEditable(
        text: widget.text,
        textModel: _textModel,
      );
    } else {
      return TxtBuild(
        text: widget.text,
        textModel: _textModel,
      );
    }
  }
}
